# Metacity Workspace

Metacity Workspace is a Python package, which is also the main Metacity application. For easy installation, follow the instructions described here.

https://github.com/MetacitySuite/Metacity-Guide